Rules and Utilities
====================

Rules
-----

.. automodule:: seagull.rules
    :members:

Utilities
---------

.. automodule:: seagull.utils

Statistics
~~~~~~~~~~

.. automodule:: seagull.utils.statistics
   :members:
